@@ -436,11 +436,12 @@ bool QRKGastroFinishTicket::payNow(int payedBy)
     }
     */
 
-    m_currentReceipt = m_receiptitemmodel->createReceipts();
-
+    bool retVal = false;
     QSqlDatabase dbc = Database::database();
     dbc.transaction();
 
+    m_currentReceipt = m_receiptitemmodel->createReceipts();
+
     bool sql_ok = true;
     if (m_currentReceipt > 0) {
         if (m_receiptitemmodel->createOrder()) {
@@ -479,7 +480,9 @@ bool QRKGastroFinishTicket::payNow(int payedBy)
 
             messageBox.exec();
         }
+        retVal = true;
     } else {
+        qCritical() << "Function Name: " << Q_FUNC_INFO << " Error: " << dbc.lastError().text();
         sql_ok = dbc.rollback();
         QMessageBox::warning(this, tr("Fehler"),
             tr("Datenbank und/oder Signatur Fehler!\nAktueller BON kann nicht "
@@ -487,7 +490,6 @@ bool QRKGastroFinishTicket::payNow(int payedBy)
                "Speicherplatz für die Datenbank vorhanden ist. Weitere Hilfe gibt "
                "es im Forum. https:://www.ckvsoft.at")
                 .arg(sql_ok ? tr("durchgeführt") : tr("fehlgeschlagen")));
-        qCritical() << "Function Name: " << Q_FUNC_INFO << " Error: " << dbc.lastError().text();
     }
 
     //    emit sendDatagram("finished", "");
@@ -499,7 +501,7 @@ bool QRKGastroFinishTicket::payNow(int payedBy)
     qDebug() << "Function Name: " << Q_FUNC_INFO
              << "Finished Time elapsed: " << dateTime.msecsTo(QDateTime::currentDateTime()) << "ms";
 
-    return true;
+    return retVal;
 }
 
 bool QRKGastroFinishTicket::finishReceipts(int payedBy, int id, bool isReport)
